BrandCode

Struct BrandCode 

pub struct BrandCode(pub FourCC);
Codes for MPEG4 brands, identifying with which specification some MP4 data is compatible .

See also,

Tuple Fields

0: FourCC

Implementations

Source

impl BrandCode

pub const ONE_PIC: BrandCode

Single intra-coded picture

FourCC: 1pic

Specification: HEIF

pub const THREE_G2A: BrandCode

3GPP2

FourCC: 3g2a

Specification: 3GPP2

pub const THREE_GE6: BrandCode

3GPP Release 6 extended-presentation Profile

FourCC: 3ge6

Specification: 3GPP

pub const THREE_GE7: BrandCode

3GPP Release 7 extended-presentation Profile

FourCC: 3ge7

Specification: 3GPP

pub const THREE_GE9: BrandCode

3GPP Release 9 Extended Presentation Profile

FourCC: 3ge9

Specification: 3GPP

pub const THREE_GF9: BrandCode

3GPP Release 9 File-delivery Server Profile

FourCC: 3gf9

Specification: 3GPP

pub const THREE_GG6: BrandCode

3GPP Release 6 General Profile

FourCC: 3gg6

Specification: 3GPP

pub const THREE_GG9: BrandCode

3GPP Release 9 General Profile

FourCC: 3gg9

Specification: 3GPP

pub const THREE_GH9: BrandCode

3GPP Release 9 Adaptive Streaming Profile

FourCC: 3gh9

Specification: 3GPP

pub const THREE_GM9: BrandCode

3GPP Release 9 Media Segment Profile

FourCC: 3gm9

Specification: 3GPP

pub const THREE_GMA: BrandCode

3GPP Media Segment conforming to the Media Segment Format for 3GP DASH

FourCC: 3gmA

Specification: 3GPP-DASH

pub const THREE_GP4: BrandCode

3GPP Release 4

FourCC: 3gp4

Specification: 3GPP

pub const THREE_GP5: BrandCode

3GPP Release 5

FourCC: 3gp5

Specification: 3GPP

pub const THREE_GP6: BrandCode

3GPP Release 6 basic Profile

FourCC: 3gp6

Specification: 3GPP

pub const THREE_GP7: BrandCode

3GPP Release 7

FourCC: 3gp7

Specification: 3GPP

pub const THREE_GP8: BrandCode

3GPP Release 8

FourCC: 3gp8

Specification: 3GPP

pub const THREE_GP9: BrandCode

3GPP Release 9 Basic Profile

FourCC: 3gp9

Specification: 3GPP

pub const THREE_GR6: BrandCode

3GPP Release 6 progressive-download Profile

FourCC: 3gr6

Specification: 3GPP

pub const THREE_GR9: BrandCode

3GPP Release 9 Progressive DownloadProfile

FourCC: 3gr9

Specification: 3GPP

pub const THREE_GS6: BrandCode

3GPP Release 6 streaming-server Profile

FourCC: 3gs6

Specification: 3GPP

pub const THREE_GS9: BrandCode

3GPP Release 9 Streaming ServerProfile

FourCC: 3gs9

Specification: 3GPP

pub const THREE_GT8: BrandCode

3GPP Release 8 Media Stream Recording Profile

FourCC: 3gt8

Specification: 3GPP

pub const THREE_GT9: BrandCode

3GPP Release 9 Media Stream Recording Profile

FourCC: 3gt9

Specification: 3GPP

pub const THREE_GTV: BrandCode

3GPP TV over 3GPP services

FourCC: 3gtv

Specification: 3GPP-TVP

pub const THREE_GVR: BrandCode

3GPP VR Presentation

FourCC: 3gvr

Specification: 3GPP-VR

pub const THREE_VRA: BrandCode

3GPP VR Advanced Video Media Profile

FourCC: 3vra

Specification: 3GPP-VR

pub const THREE_VRB: BrandCode

3GPP VR Basic Video Media Profile

FourCC: 3vrb

Specification: 3GPP-VR

pub const THREE_VRM: BrandCode

3GPP VR Main Video Media Profile

FourCC: 3vrm

Specification: 3GPP-VR

pub const ADTI: BrandCode

Advanced tiling OMAF video profile

FourCC: adti

Specification: OMAF

pub const AID3: BrandCode

ID3 metadata carried as timed metadata in CMAF

FourCC: aid3

Specification: CMAF-ID3

pub const ARRI: BrandCode

ARRI Digital Camera

FourCC: ARRI

Specification: ARRI

pub const AV01: BrandCode

AOM Video Codec

FourCC: av01

Specification: AV1-ISOBMFF

pub const AVC1: BrandCode

Advanced Video Coding extensions

FourCC: avc1

Specification: ISO

pub const AVCI: BrandCode

AVC image and image collection brands

FourCC: avci

Specification: HEIF

pub const AVCS: BrandCode

AVC image sequence brands

FourCC: avcs

Specification: HEIF

pub const AVDE: BrandCode

AVC-based viewport-dependent OMAF video profile

FourCC: avde

Specification: OMAF

pub const AVIF: BrandCode

AV1 image format brand

FourCC: avif

Specification: AVIF

pub const AVIO: BrandCode

AV1 intra-only brand

FourCC: avio

Specification: AVIF

pub const AVIS: BrandCode

AV1 image sequence brand

FourCC: avis

Specification: AVIF

pub const BBXM: BrandCode

Blinkbox Master File: H.264 video and 16-bit little-endian LPCM audio

FourCC: bbxm

Specification: Blinkbox

pub const CAEP: BrandCode

Canon Digital Camera

FourCC: CAEP

Specification: Canon

pub const CDES: BrandCode

Convergent Designs

FourCC: CDes

Specification: Convergent

pub const CA4M: BrandCode

CMAF Media Profile - AC-4 Main

FourCC: ca4m

Specification: ETSI AC-4

pub const CA4S: BrandCode

CMAF Media Profile - AC-4 Single Stream

FourCC: ca4s

Specification: ETSI AC-4

pub const CAAA: BrandCode

CMAF Media Profile - AAC Adaptive Audio

FourCC: caaa

Specification: CMAF

pub const CAAC: BrandCode

CMAF Media Profile - AAC Core

FourCC: caac

Specification: CMAF

pub const CABL: BrandCode

CMAF Media Profile for OMAF 3D audio baseline profile

FourCC: cabl

Specification: OMAF

pub const CAMA: BrandCode

CMAF Media Profile - AAC multichannel adaptive audio

FourCC: cama

Specification: CMAF

pub const CAMC: BrandCode

CMAF Media Profile - AAC multichannel audio

FourCC: camc

Specification: CMAF

pub const CAQV: BrandCode

Casio Digital Camera

FourCC: caqv

Specification: Casio

pub const CASU: BrandCode

CMAF Media Profile - MPEG-D USAC audio

FourCC: casu

Specification: CMAF

pub const CCEA: BrandCode

CMAF Supplemental Data - CEA-608/708

FourCC: ccea

Specification: CMAF

pub const CCFF: BrandCode

Common container file format

FourCC: ccff

Specification: DECE

pub const CDM1: BrandCode

CMAF Media Profile - HEVC HDR10 (chd1) with SCTE Dynamic Metadata app #1 (ST2094-10)

FourCC: cdm1

Specification: SCTE-215-1-1b

pub const CDM4: BrandCode

CMAF Media Profile compatibility to HDR10+ (ST2094-40)

FourCC: cdm4

Specification: SCTE-215-1-1b

pub const CEAC: BrandCode

CMAF Media Profile - Enhanced AC-3

FourCC: ceac

Specification: ETSI AC-3

pub const CFHD: BrandCode

CMAF Media Profile - AVC HD

FourCC: cfhd

Specification: CMAF

pub const CFSD: BrandCode

CMAF Media Profile - AVC SD

FourCC: cfsd

Specification: CMAF

pub const CHD1: BrandCode

CMAF Media Profile - HEVC HDR10

FourCC: chd1

Specification: CMAF

pub const CHDF: BrandCode

CMAF Media Profile - AVC HDHF

FourCC: chdf

Specification: CMAF

pub const CHEV: BrandCode

CMAF Media Profile for the HEVC-based viewport-dependent OMAF video profile

FourCC: chev

Specification: OMAF

pub const CHD2: BrandCode

CMAF High frame rate Media Profile - HEVC HDR10H

FourCC: chd2

Specification: CMAF

pub const CHH1: BrandCode

CMAF Media Profile - HEVC HHD10

FourCC: chh1

Specification: CMAF

pub const CHHD: BrandCode

CMAF Media Profile - HEVC HHD8

FourCC: chhd

Specification: CMAF

pub const CINT: BrandCode

CMAF Interlaced Media Profile - INT10

FourCC: cint

Specification: CMAF

pub const CLG1: BrandCode

CMAF Media Profile - HEVC HLG10

FourCC: clg1

Specification: CMAF

pub const CLG2: BrandCode

CMAF High frame rate Media Profile - HEVC HLG10H

FourCC: clg2

Specification: CMAF

pub const CMF2: BrandCode

CMAF Structural Brand

FourCC: cmf2

Specification: CMAF

pub const CMFC: BrandCode

CMAF Structural Brand

FourCC: cmfc

Specification: CMAF

pub const CMFF: BrandCode

CMAF Fragment Format

FourCC: cmff

Specification: CMAF

pub const CMFL: BrandCode

CMAF Chunk Format

FourCC: cmfl

Specification: CMAF

pub const CMFS: BrandCode

CMAF Segment Format

FourCC: cmfs

Specification: CMAF

pub const CMHM: BrandCode

CMAF Media Profile - MPEG-H 3D audio LC (mhm2)

FourCC: cmhm

Specification: CMAF

pub const CMHS: BrandCode

CMAF Media Profile - MPEG-H 3D audio LC (mhm1)

FourCC: cmhs

Specification: CMAF

pub const COMP: BrandCode

Compressed boxes

FourCC: comp

Specification: ISO

pub const CSH1: BrandCode

CMAF Media Profile - Scalable HEVC media profile

FourCC: csh1

Specification: CMAF

pub const CUD1: BrandCode

CMAF Media Profile - HEVC UHD10

FourCC: cud1

Specification: CMAF

pub const CUD2: BrandCode

CMAF High frame rate Media Profile - HEVC UHD10H

FourCC: cud2

Specification: CMAF

pub const CUD8: BrandCode

CMAF Media Profile - HEVC UHD8

FourCC: cud8

Specification: CMAF

pub const CUD9: BrandCode

CMAF High frame rate Media Profile - HEVC UHD8H

FourCC: cud9

Specification: CMAF

pub const CUVD: BrandCode

CMAF Media Profile for the unconstrained HEVC-based viewport-independent OMAF video profile

FourCC: cuvd

Specification: OMAF

pub const CVID: BrandCode

CMAF Media Profile for the HEVC-based viewport-independent OMAF video profile

FourCC: cvid

Specification: OMAF

pub const CVVC: BrandCode

Baseline VVC media profile

FourCC: cvvc

Specification: CMAF

pub const CWVT: BrandCode

CMAF Media Profile - WebVTT

FourCC: cwvt

Specification: CMAF

pub const DA0A: BrandCode

DMB AF audio with MPEG Layer II audio, MOT slide show, DLS, JPG/PNG/MNG images

FourCC: da0a

Specification: DMB-MAF

pub const DA0B: BrandCode

DMB AF, extending da0a , with 3GPP timed text, DID, TVA, REL, IPMP

FourCC: da0b

Specification: DMB-MAF

pub const DA1A: BrandCode

DMB AF audio with ER-BSAC audio, JPG/PNG/MNG images

FourCC: da1a

Specification: DMB-MAF

pub const DA1B: BrandCode

DMB AF, extending da1a, with 3GPP timed text, DID, TVA, REL, IPMP

FourCC: da1b

Specification: DMB-MAF

pub const DA2A: BrandCode

DMB AF audio with HE-AAC v2 audio, MOT slide show, DLS, JPG/PNG/MNG images

FourCC: da2a

Specification: DMB-MAF

pub const DA2B: BrandCode

DMB AF extending da2a, with 3GPP timed text, DID, TVA, REL, IPMP

FourCC: da2b

Specification: DMB-MAF

pub const DA3A: BrandCode

DMB AF audio with HE-AAC, JPG/PNG/MNG images

FourCC: da3a

Specification: DMB-MAF

pub const DA3B: BrandCode

DMB AF extending da3a with BIFS, 3GPP timed text, DID, TVA, REL, IPMP

FourCC: da3b

Specification: DMB-MAF

pub const DASH: BrandCode

ISO base media file format file specifically designed for DASH including movie fragments and Segment Index.

FourCC: dash

Specification: DASH

pub const DB1P: BrandCode

Dolby Vision cross-compatible with HDR10

FourCC: db1p

Specification: Dolby

pub const DB2G: BrandCode

Dolby Vision cross-compatible with SDR

FourCC: db2g

Specification: Dolby

pub const DB4H: BrandCode

Dolby Vision cross-compatible with HLG (VUI =18)

FourCC: db4h

Specification: Dolby

pub const DB4G: BrandCode

Dolby Vision cross-compatible with HLG (VUI=14)

FourCC: db4g

Specification: Dolby

pub const DBY1: BrandCode

MP4 files with Dolby content (e.g. Dolby AC-4, Dolby Digital Plus, Dolby TrueHD (Dolby MLP))

FourCC: dby1

Specification: Dolby

pub const DMB1: BrandCode

DMB AF supporting all the components defined in the specification

FourCC: dmb1

Specification: DMB-MAF

pub const DSMS: BrandCode

Media Segment conforming to the DASH Self-Initializing Media Segment format type for ISO base media file format

FourCC: dsms

Specification: DASH

pub const DTS1: BrandCode

CMAF media profile for audio codecs dtsc dtsh or dtse

FourCC: dts1

Specification: DTS-HD

pub const DTS2: BrandCode

CMAF media profile for audio codec dtsx

FourCC: dts2

Specification: DTS-UHD

pub const DTS3: BrandCode

CMAF media profile for audio codec dtsy

FourCC: dts3

Specification: DTS-UHD

pub const DV1A: BrandCode

DMB AF video with AVC video, ER-BSAC audio, BIFS, JPG/PNG/MNG images, TS

FourCC: dv1a

Specification: DMB-MAF

pub const DV1B: BrandCode

DMB AF, extending dv1a, with 3GPP timed text, DID, TVA, REL, IPMP

FourCC: dv1b

Specification: DMB-MAF

pub const DV2A: BrandCode

DMB AF video with AVC video, HE-AACv2 audio, BIFS, JPG/PNG/MNG images, TS

FourCC: dv2a

Specification: DMB-MAF

pub const DV2B: BrandCode

DMB AF extending dv2a, with 3GPP timed text, DID, TVA, REL, IPMP

FourCC: dv2b

Specification: DMB-MAF

pub const DV3A: BrandCode

DMB AF video with AVC video, HE-AAC audio, BIFS, JPG/PNG/MNG images, TS

FourCC: dv3a

Specification: DMB-MAF

pub const DV3B: BrandCode

DMB AF extending dv3a with 3GPP timed text, DID, TVA, REL, IPMP

FourCC: dv3b

Specification: DMB-MAF

pub const DVR1: BrandCode

DVB RTP

FourCC: dvr1

Specification: DVB

pub const DVT1: BrandCode

DVB Transport Stream

FourCC: dvt1

Specification: DVB

pub const DXO: BrandCode

DxO ONE camera

FourCC: dxo

Specification: DxO

pub const EMSG: BrandCode

Event message box present

FourCC: emsg

Specification: DASH

pub const EVBI: BrandCode

EVC Baseline coded image

FourCC: evbi

Specification: HEIF

pub const EVBS: BrandCode

EVC Baseline coded image sequence

FourCC: evbs

Specification: HEIF

pub const EVMI: BrandCode

EVC Main coded image

FourCC: evmi

Specification: HEIF

pub const EVMS: BrandCode

EVC Main coded image sequenc

FourCC: evms

Specification: HEIF

pub const HEIC: BrandCode

HEVC image and image collection brands

FourCC: heic

Specification: HEIF

pub const HEIM: BrandCode

L-HEVC image and image collection brands

FourCC: heim

Specification: HEIF

pub const HEIS: BrandCode

L-HEVC image and image collection brands

FourCC: heis

Specification: HEIF

pub const HEIX: BrandCode

HEVC image and image collection brands

FourCC: heix

Specification: HEIF

pub const HEOI: BrandCode

OMAF HEVC image profile

FourCC: heoi

Specification: OMAF

pub const HEVC: BrandCode

HEVC image sequence brands

FourCC: hevc

Specification: HEIF

pub const HEVD: BrandCode

HEVC-based viewport-dependent OMAF video profile

FourCC: hevd

Specification: OMAF

pub const HEVI: BrandCode

HEVC-based viewport-independent OMAF video profile

FourCC: hevi

Specification: OMAF

pub const HEVM: BrandCode

L-HEVC image sequence brands

FourCC: hevm

Specification: HEIF

pub const HEVS: BrandCode

L-HEVC image sequence brands

FourCC: hevs

Specification: HEIF

pub const HEVX: BrandCode

HEVC image sequence brands

FourCC: hevx

Specification: HEIF

pub const HVCE: BrandCode

L-HEVC explicit reconstruction

FourCC: hvce

Specification: NALu Video

pub const HVCI: BrandCode

L-HEVC implicit reconstruction

FourCC: hvci

Specification: NALu Video

pub const HVCX: BrandCode

L-HEVC extended explicit reconstruction brand

FourCC: hvcx

Specification: NALu Video

pub const HVTI: BrandCode

HEVC Tile Track

FourCC: hvti

Specification: NALu Video

pub const IFSD: BrandCode

The IFE-SD Media Profile

FourCC: ifsd

Specification: IFE

pub const IFHS: BrandCode

The IFE-HSD Media Profile

FourCC: ifhs

Specification: IFE

pub const IFHD: BrandCode

The IFE-HD Media Profile

FourCC: ifhd

Specification: IFE

pub const IFHX: BrandCode

The IFE-HHD10 Media Profile

FourCC: ifhx

Specification: IFE

pub const IFHH: BrandCode

The IFE-HDHDR Media Profile

FourCC: ifhh

Specification: IFE

pub const IFHU: BrandCode

The IFE-UHD10 Media Profile

FourCC: ifhu

Specification: IFE

pub const IFHR: BrandCode

The IFE-HDR10 Media Profile

FourCC: ifhr

Specification: IFE

pub const IFAA: BrandCode

The IFE-AAC Core Media Profile

FourCC: ifaa

Specification: IFE

pub const IFAS: BrandCode

The IFE-AV1-SD Media Profile

FourCC: ifas

Specification: IFE

pub const IFAH: BrandCode

The IFE-AV1-HD Media Profile

FourCC: ifah

Specification: IFE

pub const IFAI: BrandCode

The IFE-AV1-HDHDR Media Profile

FourCC: ifai

Specification: IFE

pub const IFAU: BrandCode

The IFE-AV1-UHD10 Media Profile

FourCC: ifau

Specification: IFE

pub const IFAV: BrandCode

The IFE-AV1-HDR10 Media Profile

FourCC: ifav

Specification: IFE

pub const IFRM: BrandCode

Apple iFrame Specification, Version 8.1 Jan 2013

FourCC: ifrm

Specification: Apple

pub const IM1I: BrandCode

CMAF Media Profile - IMSC1 Image

FourCC: im1i

Specification: CMAF

pub const IM1T: BrandCode

CMAF Media Profile - IMSC1 Text

FourCC: im1t

Specification: CMAF

pub const IM2I: BrandCode

CMAF Media Profile - IMSC1.1 Image

FourCC: im2i

Specification: CMAF

pub const IM2T: BrandCode

CMAF Media Profile - IMSC1.1 Text

FourCC: im2t

Specification: CMAF

pub const ISC2: BrandCode

Files encrypted according to ISMACryp 2.0

FourCC: isc2

Specification: ISMACryp2

pub const ISO2: BrandCode

All files based on the 2004 edition of the ISO file format

FourCC: iso2

Specification: ISO

pub const ISO3: BrandCode

Version of the ISO file format

FourCC: iso3

Specification: ISO

pub const ISO4: BrandCode

Version of the ISO file format

FourCC: iso4

Specification: ISO

pub const ISO5: BrandCode

Version of the ISO file format

FourCC: iso5

Specification: ISO

pub const ISO6: BrandCode

Version of the ISO file format

FourCC: iso6

Specification: ISO

pub const ISO7: BrandCode

Version of the ISO file format

FourCC: iso7

Specification: ISO

pub const ISO8: BrandCode

Version of the ISO file format

FourCC: iso8

Specification: ISO

pub const ISO9: BrandCode

Version of the ISO file format

FourCC: iso9

Specification: ISO

pub const ISOA: BrandCode

Version of the ISO file format

FourCC: isoa

Specification: ISO

pub const ISOB: BrandCode

Version of the ISO file format

FourCC: isob

Specification: ISO

pub const ISOC: BrandCode

Version of the ISO file format

FourCC: isoc

Specification: ISO

pub const ISOM: BrandCode

All files based on the ISO Base Media File Format

FourCC: isom

Specification: ISO

pub const J2KI: BrandCode

JPEG 2000 image and image collections in ISO/IEC 23008-12 files

FourCC: j2ki

Specification: J2KHEIF

pub const J2KS: BrandCode

Motion JPEG 2000 in ISO/IEC 23008-12 files

FourCC: j2ks

Specification: J2KHEIF

pub const J2IS: BrandCode

JPEG 2000 image sequence in ISO/IEC 23008-12 files

FourCC: j2is

Specification: J2KHEIF

pub const J2P0: BrandCode

JPEG2000 Profile 0

FourCC: J2P0

Specification: JPEG2000

pub const J2P1: BrandCode

JPEG2000 Profile 1

FourCC: J2P1

Specification: JPEG2000

pub const JP2: BrandCode

JPEG2000 Part 1

FourCC: jp2

Specification: JPEG2000

pub const JPEG: BrandCode

JPEG-specific still image brand

FourCC: jpeg

Specification: HEIF

pub const JPGS: BrandCode

JPEG image sequence brands

FourCC: jpgs

Specification: HEIF

pub const JPM: BrandCode

JPEG 2000 Part 6 Compound Images

FourCC: jpm

Specification: JPM

pub const JPOI: BrandCode

OMAF legacy image profile

FourCC: jpoi

Specification: OMAF

pub const JPSI: BrandCode

The JPSearch data interchange format, for the exchange of image collections and respective metadata

FourCC: jpsi

Specification: JPSearch

pub const JPX: BrandCode

JPEG2000 Part 2

FourCC: jpx

Specification: JPX

pub const JPXB: BrandCode

JPEG XR

FourCC: jpxb

Specification: JPXR

pub const JXL: BrandCode

JPEG XL

FourCC: jxl

Specification: JPEG XL

pub const JXS: BrandCode

Still Image File Format for JPEG XS

FourCC: jxs

Specification: JPXS

pub const JXSC: BrandCode

Codestream for JPEG XS

FourCC: jxsc

Specification: JPXS

pub const JXSI: BrandCode

JPEG XS image and image collections for HEIF

FourCC: jxsi

Specification: JPXS

pub const JXSS: BrandCode

JPEG XS image sequences for HEIF

FourCC: jxss

Specification: JPXS

pub const LCAG: BrandCode

Leica digital camera

FourCC: LCAG

Specification: Leica

pub const LHTE: BrandCode

L-HEVC Tile Track Explicit brand

FourCC: lhte

Specification: NALu Video

pub const LHTI: BrandCode

L-HEVC Tile Track Implicit brand

FourCC: lhti

Specification: NALu Video

pub const LMSG: BrandCode

last Media Segment indicator for ISO base media file format.

FourCC: lmsg

Specification: DASH

pub const M4A: BrandCode

iTunes MPEG-4 audio protected or not, can contain audio + video + 3g text track + chapter track

FourCC: M4A

Specification: iTunes

pub const M4B: BrandCode

iTunes AudioBook protected or not, can contain audio + video + 3g text track + chapter track

FourCC: M4B

Specification: iTunes

pub const M4P: BrandCode

MPEG-4 protected audio

FourCC: M4P

Specification: iTunes

pub const M4V: BrandCode

MPEG-4 protected audio+video

FourCC: M4V

Specification: iTunes

pub const MA1B: BrandCode

AVIF Baseline Profile

FourCC: MA1B

Specification: AVIF

pub const MA1A: BrandCode

AVIF Advanced Profile

FourCC: MA1A

Specification: AVIF

pub const MFSM: BrandCode

Media File for Samsung video Metadata

FourCC: MFSM

Specification: Samsung

pub const MGSV: BrandCode

Home and Mobile Multimedia Platform (HMMP)

FourCC: MGSV

Specification: Sony

pub const MIAB: BrandCode

Multi-Image Application format brand for MIAF AVC Basic Profile

FourCC: MiAB

Specification: MIAF

pub const MIAC: BrandCode

Multi-Image Application format brand for fragmented alpha video

FourCC: MiAC

Specification: MIAF

pub const MIAF: BrandCode

Multi-Image Application format brand for general MIAF requirements

FourCC: miaf

Specification: MIAF

pub const MIAN: BrandCode

Mutli-Image Application format brand for animation

FourCC: MiAn

Specification: MIAF

pub const MIBU: BrandCode

Multi-Image Application format brand for burst capture

FourCC: MiBu

Specification: MIAF

pub const MICM: BrandCode

Multi-Image Application format brand for CMAF compatibility

FourCC: MiCm

Specification: MIAF

pub const MIF1: BrandCode

Image file format structural brand

FourCC: mif1

Specification: HEIF

pub const MIF2: BrandCode

Image file format structural brand CICP alpha and depth

FourCC: mif2

Specification: HEIF

pub const MIHA: BrandCode

Multi-Image Application format brand for MIAF HEVC Advanced Profile

FourCC: MiHA

Specification: MIAF

pub const MIHB: BrandCode

Multi-Image Application format brand for MIAF HEVC Basic Profile

FourCC: MiHB

Specification: MIAF

pub const MIHE: BrandCode

Multi-Image Application format brand for MIAF HEVC Extended Profile

FourCC: MiHE

Specification: MIAF

pub const MIPR: BrandCode

Multi-Image Application format brand for progressive decoding and rendering

FourCC: MiPr

Specification: MIAF

pub const MJ2S: BrandCode

Motion JPEG 2000 simple profile

FourCC: mj2s

Specification: MJ2

pub const MJP2: BrandCode

Motion JPEG 2000, general profile

FourCC: mjp2

Specification: MJ2

pub const MP21: BrandCode

MPEG-21

FourCC: mp21

Specification: MPEG-21

pub const MP41: BrandCode

MP4 version 1

FourCC: mp41

Specification: MP4v2

pub const MP42: BrandCode

MP4 version 2

FourCC: mp42

Specification: MP4v2

pub const MP71: BrandCode

MPEG-7 file-level metadata

FourCC: mp71

Specification: ISO

pub const MPPI: BrandCode

Photo Player Multimedia Application Format

FourCC: MPPI

Specification: ISO-MAF

pub const MPUF: BrandCode

Compliance with the MMT Processing Unit format

FourCC: mpuf

Specification: MMT

pub const MSF1: BrandCode

Image file format structural brand

FourCC: msf1

Specification: HEIF

pub const MSDH: BrandCode

Media Segment conforming to the general format type for ISO base media file format.

FourCC: msdh

Specification: DASH

pub const MSIX: BrandCode

Media Segment conforming to the Indexed Media Segment format type for ISO base media file format.

FourCC: msix

Specification: DASH

pub const MSNV: BrandCode

Portable multimedia CE products using MP4 file format with AVC video codec and AAC audio codec

FourCC: MSNV

Specification: IEC 62592

pub const NIKO: BrandCode

Nikon Digital Camera

FourCC: niko

Specification: Nikon

pub const NLSL: BrandCode

Non-linear storyline toolset brand

FourCC: nlsl

Specification: OMAF

pub const NRAS: BrandCode

No Leading Picture Sync Brand

FourCC: nras

Specification: NALu Video

pub const OA2D: BrandCode

OMAF 2D audio legacy profile

FourCC: oa2d

Specification: OMAF

pub const OABL: BrandCode

OMAF 3D audio baseline profile

FourCC: oabl

Specification: OMAF

pub const ODCF: BrandCode

OMA DCF (DRM Content Format)

FourCC: odcf

Specification: OMA DRM 2.0

pub const OMPP: BrandCode

OMAF viewport-independent baseline presentation profile

FourCC: ompp

Specification: OMAF

pub const OPF2: BrandCode

OMA PDCF (DRM Content Format)

FourCC: opf2

Specification: OMA DRM 2.1

pub const OPX2: BrandCode

OMA Adapted PDCF

FourCC: opx2

Specification: OMA DRM XBS

pub const OVDP: BrandCode

OMAF viewport-dependent baseline presentation profile

FourCC: ovdp

Specification: OMAF

pub const OVLY: BrandCode

Overlay toolset brand

FourCC: ovly

Specification: OMAF

pub const PAFF: BrandCode

Generic Partial File

FourCC: paff

Specification: ISO-Partial

pub const PANA: BrandCode

Panasonic Digital Camera

FourCC: pana

Specification: Panasonic

pub const PIFF: BrandCode

Protected Interoperable File Format

FourCC: piff

Specification: PIFF

pub const PMFF: BrandCode

Mixed Partial File

FourCC: pmff

Specification: ISO-Partial

pub const PNVI: BrandCode

Panasonic Video Intercom

FourCC: pnvi

Specification: Panasonic Video Intercom

pub const PRED: BrandCode

Image file format brand for predictively coded image items

FourCC: pred

Specification: HEIF

pub const QT: BrandCode

QuickTime

FourCC: qt

Specification: QT

pub const RELO: BrandCode

combination brand to indicate relative addressing

FourCC: relo

Specification: ISO

pub const RISX: BrandCode

Representation Index Segment used to index MPEG-2 TS based Media Segments.

FourCC: risx

Specification: DASH

pub const ROSS: BrandCode

Ross Video

FourCC: ROSS

Specification: Ross

pub const SDV: BrandCode

SD Video

FourCC: sdv

Specification: SDV

pub const SEAU: BrandCode

Home and Mobile Multimedia Platform (HMMP)

FourCC: SEAU

Specification: Sony

pub const SEBK: BrandCode

Home and Mobile Multimedia Platform (HMMP)

FourCC: SEBK

Specification: Sony

pub const SENV: BrandCode

Video contents Sony Entertainment Network provides by using MP4 file format

FourCC: senv

Specification: Sony

pub const SIMS: BrandCode

Media Segment conforming to the Sub-Indexed Media Segment format type for ISO base media file format.

FourCC: sims

Specification: DASH

pub const SISX: BrandCode

Single Index Segment used to index MPEG-2 TS based Media Segments.

FourCC: sisx

Specification: DASH

pub const SITI: BrandCode

HEVC-based simple tiling OMAF video profile

FourCC: siti

Specification: OMAF

pub const SITV: BrandCode

VVC-based simple tiling OMAF video profile

FourCC: sitv

Specification: OMAF

pub const SLH1: BrandCode

Dynamic metadata for Single Layer SDR-compatible HDR video streams

FourCC: slh1

Specification: SL-HDR

pub const SLH2: BrandCode

Dynamic metadata for Single Layer PQ-based HDR video streams

FourCC: slh2

Specification: SL-HDR

pub const SLH3: BrandCode

Dynamic metadata for Single Layer HLG-based HDR video streams

FourCC: slh3

Specification: SL-HDR

pub const SSSS: BrandCode

Subsegment Index Segment used to index MPEG-2 TS based Media Segments.

FourCC: ssss

Specification: DASH

pub const TTML: BrandCode

OMAF IMSC1 timed text profile

FourCC: ttml

Specification: OMAF

pub const TTWV: BrandCode

OMAF WebVTT timed text profile

FourCC: ttwv

Specification: OMAF

pub const UHVI: BrandCode

Unconstrained HEVC-based viewport-independent OMAF video profile

FourCC: uhvi

Specification: OMAF

pub const UNIF: BrandCode

Unified identifiers

FourCC: unif

Specification: ISO

pub const UVVU: BrandCode

UltraViolet file brand – conforming to the DECE Common File Format spec, Annex E.

FourCC: uvvu

Specification: DECE

pub const V3MP: BrandCode

Multi-track encapsulation mode for V3C data with partial access support

FourCC: v3mp

Specification: V3C-SYS

pub const V3MT: BrandCode

Multi-track encapsulation mode for V3C data

FourCC: v3mt

Specification: V3C-SYS

pub const V3NT: BrandCode

Non-timed encpasulation mode for V3C data

FourCC: v3nt

Specification: V3C-SYS

pub const V3ST: BrandCode

Single-track encapsulation mode for V3C data

FourCC: v3st

Specification: V3C-SYS

pub const VVCI: BrandCode

VVC-based viewport-independent OMAF video profile

FourCC: vvci

Specification: OMAF

pub const VVIC: BrandCode

VVC coded image item

FourCC: vvic

Specification: HEIF

pub const VVIS: BrandCode

VVC coded image sequence

FourCC: vvis

Specification: HEIF

pub const VVOI: BrandCode

OMAF VVC image profile

FourCC: vvoi

Specification: OMAF

pub const VWPT: BrandCode

Viewpoint toolset brand

FourCC: vwpt

Specification: OMAF

pub const XAVC: BrandCode

XAVC File Format

FourCC: XAVC

Specification: Sony

pub const YT4: BrandCode

Google specification for use by YouTube apps

FourCC: yt4

Specification: Youtube

pub const IAMF: BrandCode

Immersive Audio Model and Formats - Encapsulated IA Sequence

FourCC: iamf

Specification: AOM-IAMF

pub const MUXA: BrandCode

Apple HEVC Video with Alpha

FourCC: muxa

Specification: Apple HEVC Alpha

pub const CVVM: BrandCode

CMAF Media Profile for Constrained Multilayer VVC

FourCC: cvvm

Specification: ATSC 3.0 A345

pub const CAFR: BrandCode

CMAF Media Profile for ATSC Full Range Constrained Baseline VVC

FourCC: cafr

Specification: ATSC 3.0 A345

pub const XFVC: BrandCode

XF-AVC S/XF-HEVC S File Format

FourCC: XFVC

Specification: Canon

pub const CA3A: BrandCode

CMAF Media Profile – AVS3-P3

FourCC: ca3a

Specification: T-AI-109.7

pub const CLV1: BrandCode

CMAF Media Profile for MPEG-5 LCEVC

FourCC: clv1

Specification: CMAF

pub const ISOD: BrandCode

Version of the ISO file format

FourCC: isod

Specification: ISO

pub const CEVB: BrandCode

CMAF EVC Baseline Media Profile

FourCC: cevb

Specification: CMAF

pub const CEVM: BrandCode

CMAF EVC Main Media Profile

FourCC: cevm

Specification: CMAF

pub const CMFR: BrandCode

CMAF Random Access chunk

FourCC: cmfr

Specification: CMAF

pub const CMH1: BrandCode

MPEG-H audio BL single-stream media profile

FourCC: cmh1

Specification: CMAF

pub const CMH2: BrandCode

MPEG-H audio BL multi-stream media profile

FourCC: cmh2

Specification: CMAF

pub const SAIE: BrandCode

SampleAuxiliaryInformationSizesBox with version 1 and 2

FourCC: saie

Specification: ISO

Source

impl BrandCode

pub const fn new(code: [u8; 4]) -> BrandCode

Construct a BrandCode from its four-cc value