TrackReferenceCode

Struct TrackReferenceCode 

pub struct TrackReferenceCode(pub FourCC);
Codes for track reference link types.

See also,

Tuple Fields

0: FourCC

Implementations

Source

impl TrackReferenceCode

pub const ADDA: TrackReferenceCode

Additional audio track

FourCC: adda

Specification: ISO

pub const ADRC: TrackReferenceCode

DRC metadata track

FourCC: adrc

Specification: ISO

pub const AUXL: TrackReferenceCode

Auxiliary track reference

FourCC: auxl

Specification: ISO

pub const AVCP: TrackReferenceCode

AVC parameter set stream link

FourCC: avcp

Specification: NALu Video

pub const CDSC: TrackReferenceCode

this track describes the referenced track.

FourCC: cdsc

Specification: ISO

pub const CDTG: TrackReferenceCode

this track describes the referenced tracks and track groups collectively

FourCC: cdtg

Specification: OMAF

pub const DEPS: TrackReferenceCode

track containing the depth view

FourCC: deps

Specification: NALu Video

pub const DPND: TrackReferenceCode

this track has an MPEG-4 dependency on the referenced track

FourCC: dpnd

Specification: MP4v2

pub const EVCR: TrackReferenceCode

EVC slice base track

FourCC: evcr

Specification: NALu Video

pub const FONT: TrackReferenceCode

this track uses fonts carried/defined in the referenced track

FourCC: font

Specification: ISO

pub const HIND: TrackReferenceCode

Hint dependency

FourCC: hind

Specification: ISO

pub const HINT: TrackReferenceCode

links hint track to original media track

FourCC: hint

Specification: ISO

pub const IPIR: TrackReferenceCode

this track contains IPI declarations for the referenced track

FourCC: ipir

Specification: MP4v2

pub const LYRA: TrackReferenceCode

Audio layer track dependency

FourCC: lyra

Specification: DTS

pub const MIXN: TrackReferenceCode

used in indicating combinations that result into mixed network abstraction layer unit types in a coded picture of VVC

FourCC: mixn

Specification: NALu Video

pub const MPOD: TrackReferenceCode

this track is an OD track which uses the referenced track as an included elementary stream track

FourCC: mpod

Specification: MP4v2

pub const OREF: TrackReferenceCode

track that contains an ‘oref’ sample group

FourCC: oref

Specification: NALu Video

pub const RECR: TrackReferenceCode

resolved by extracting an indicated subset of the referenced VVC track to reconstruct a VVC bitstream

FourCC: recr

Specification: NALu Video

pub const SABT: TrackReferenceCode

HEVC Tile Track

FourCC: sabt

Specification: NALu Video

pub const SBAS: TrackReferenceCode

Scalable base

FourCC: sbas

Specification: NALu Video

pub const SCAL: TrackReferenceCode

Scalable extraction

FourCC: scal

Specification: NALu Video

pub const SHSC: TrackReferenceCode

reference to a shadow sync sample track

FourCC: shsc

Specification: OMAF

pub const SUBP: TrackReferenceCode

the referenced VVC subpicture tracks or ‘alte’ track groups of VVC subpicture tracks are used to reconstruct a VVC bitstream

FourCC: subp

Specification: NALu Video

pub const SUBT: TrackReferenceCode

subtitle or timed text or overlay graphical information

FourCC: subt

Specification: ISO

pub const SWFR: TrackReferenceCode

AVC Switch from

FourCC: swfr

Specification: NALu Video

pub const SWTO: TrackReferenceCode

AVC Switch to

FourCC: swto

Specification: NALu Video

pub const SYNC: TrackReferenceCode

this track uses the referenced track as its synchronization source.

FourCC: sync

Specification: MP4v2

pub const TBAS: TrackReferenceCode

HEVC Tile track base

FourCC: tbas

Specification: NALu Video

pub const THMB: TrackReferenceCode

Thumbnail track reference

FourCC: thmb

Specification: ISO

pub const TMCD: TrackReferenceCode

Time code. Usually references a time code track.

FourCC: tmcd

Specification: Apple

pub const V3CS: TrackReferenceCode

V3C atlas track

FourCC: v3cs

Specification: V3C-SYS

pub const V3CT: TrackReferenceCode

V3C atlas tile track

FourCC: v3ct

Specification: V3C-SYS

pub const V3VA: TrackReferenceCode

V3C attribute video track

FourCC: v3va

Specification: V3C-SYS

pub const V3VG: TrackReferenceCode

V3C geometry video track

FourCC: v3vg

Specification: V3C-SYS

pub const V3VO: TrackReferenceCode

V3C occupancy video track

FourCC: v3vo

Specification: V3C-SYS

pub const VDEP: TrackReferenceCode

Auxiliary video depth

FourCC: vdep

Specification: ISO

pub const VPLX: TrackReferenceCode

Auxiliary video parallax

FourCC: vplx

Specification: ISO

pub const VREF: TrackReferenceCode

reference to a track that contains a ‘vopi’ sample group for VVC video

FourCC: vref

Specification: NALu Video

pub const VREG: TrackReferenceCode

reference to a VVC operating point entity group

FourCC: vreg

Specification: NALu Video

pub const VVCN: TrackReferenceCode

the referenced track is a non video coding layer track of VVC

FourCC: vvcN

Specification: NALu Video

pub const SUPM: TrackReferenceCode

The referenced tracks provide supplementary video to achieve picture-in-picture functionality

FourCC: supm

Specification: NALu Video

pub const AEST: TrackReferenceCode

associated external stream track

FourCC: aest

Specification: ISO

pub const RNDR: TrackReferenceCode

Rendering-related metadata

FourCC: rndr

Specification: Apple

Source

impl TrackReferenceCode

pub const fn new(code: [u8; 4]) -> TrackReferenceCode

Construct a TrackReferenceCode from its four-cc value